==> edc_test_utils-0.3.29-py3-none-any.whl: edc_test_utils/default_installed_apps.py <==
DEFAULT_EDC_INSTALLED_APPS = [
    "defender",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.messages",
    "django.contrib.sessions",
    "django.contrib.sites",
    "django.contrib.staticfiles",
    "django_crypto_fields.apps.AppConfig",
    "django_extensions",
    "django_revision.apps.AppConfig",
    "logentry_admin",
    "multisite",
    "simple_history",
    "storages",
    "edc_action_item.apps.AppConfig",
    "edc_appointment.apps.AppConfig",
    "edc_adverse_event.apps.AppConfig",
    "edc_crf.apps.AppConfig",
    "edc_consent.apps.AppConfig",
    "edc_lab.apps.AppConfig",
    "edc_visit_schedule.apps.AppConfig",
    "edc_dashboard.apps.AppConfig",
    "edc_data_manager.apps.AppConfig",
    "edc_device.apps.AppConfig",
    "edc_export.apps.AppConfig",
    "edc_fieldsets.apps.AppConfig",
    "edc_facility.apps.AppConfig",
    "edc_form_describer.apps.AppConfig",
    "edc_identifier.apps.AppConfig",
    "edc_lab_dashboard.apps.AppConfig",
    "edc_label.apps.AppConfig",
    "edc_list_data.apps.AppConfig",
    "edc_listboard.apps.AppConfig",
    "edc_locator.apps.AppConfig",
    "edc_reference.apps.AppConfig",
    "edc_metadata.apps.AppConfig",
    "edc_model.apps.AppConfig",
    "edc_model_admin.apps.AppConfig",
    "edc_navbar.apps.AppConfig",
    "edc_notification.apps.AppConfig",
    "edc_offstudy.apps.AppConfig",
    "edc_pharmacy.apps.AppConfig",
    "edc_pdutils.apps.AppConfig",
    "edc_protocol.apps.AppConfig",
    "edc_protocol_violation.apps.AppConfig",
    "edc_prn.apps.AppConfig",
    "edc_randomization.apps.AppConfig",
    "edc_registration.apps.AppConfig",
    "edc_reportable.apps.AppConfig",
    "edc_pdf_reports.apps.AppConfig",
    "edc_review_dashboard.apps.AppConfig",
    "edc_sites.apps.AppConfig",
    "edc_subject_dashboard.apps.AppConfig",
    "edc_timepoint.apps.AppConfig",
    "edc_unblinding.apps.AppConfig",
    "edc_visit_tracking.apps.AppConfig",
    "adverse_event_app.apps.AppConfig",
    "edc_auth.apps.AppConfig",
]

==> edc_test_utils-0.3.47-py3-none-any.whl: edc_test_utils/default_installed_apps.py <==
DEFAULT_EDC_INSTALLED_APPS = [
    "defender",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.messages",
    "django.contrib.sessions",
    "django.contrib.sites",
    "django.contrib.staticfiles",
    "django_crypto_fields.apps.AppConfig",
    "django_extensions",
    "django_revision.apps.AppConfig",
    "logentry_admin",
    "multisite",
    "simple_history",
    "storages",
    "edc_action_item.apps.AppConfig",
    "edc_appointment.apps.AppConfig",
    "edc_adverse_event.apps.AppConfig",
    "edc_crf.apps.AppConfig",
    "edc_consent.apps.AppConfig",
    "edc_lab.apps.AppConfig",
    "edc_visit_schedule.apps.AppConfig",
    "edc_dashboard.apps.AppConfig",
    "edc_data_manager.apps.AppConfig",
    "edc_device.apps.AppConfig",
    "edc_export.apps.AppConfig",
    "edc_fieldsets.apps.AppConfig",
    "edc_facility.apps.AppConfig",
    "edc_form_describer.apps.AppConfig",
    "edc_identifier.apps.AppConfig",
    "edc_lab_dashboard.apps.AppConfig",
    "edc_label.apps.AppConfig",
    "edc_list_data.apps.AppConfig",
    "edc_listboard.apps.AppConfig",
    "edc_locator.apps.AppConfig",
    "edc_metadata.apps.AppConfig",
    "edc_model.apps.AppConfig",
    "edc_model_admin.apps.AppConfig",
    "edc_navbar.apps.AppConfig",
    "edc_notification.apps.AppConfig",
    "edc_offstudy.apps.AppConfig",
    "edc_pharmacy.apps.AppConfig",
    "edc_pdutils.apps.AppConfig",
    "edc_protocol.apps.AppConfig",
    "edc_protocol_incident.apps.AppConfig",
    "edc_prn.apps.AppConfig",
    "edc_randomization.apps.AppConfig",
    "edc_registration.apps.AppConfig",
    "edc_reportable.apps.AppConfig",
    "edc_pdf_reports.apps.AppConfig",
    "edc_review_dashboard.apps.AppConfig",
    "edc_sites.apps.AppConfig",
    "edc_subject_dashboard.apps.AppConfig",
    "edc_timepoint.apps.AppConfig",
    "edc_unblinding.apps.AppConfig",
    "edc_visit_tracking.apps.AppConfig",
    "adverse_event_app.apps.AppConfig",
    "edc_auth.apps.AppConfig",
]
